
# Contrib folder

This folder contains additional functions that are useful but do not belong to the core of gate.
The functions are used in several tests.

See the file `user_guide_contrib.md` in the folder `docs/` or the online doc:
https://opengate-python.readthedocs.io/en/latest/user_guide.html
